about summary refs log tree commit diff
path: root/src/ci
diff options
context:
space:
mode:
authorbit-aloo <sshourya17@gmail.com>2025-02-15 20:17:03 +0530
committerbit-aloo <sshourya17@gmail.com>2025-03-17 12:56:49 +0530
commit99aa4ed85f15af7c71ea6c2e46eae36f8bc78894 (patch)
tree7ff5d0bea9fa1e0bd05fe1825c3338729571a7b9 /src/ci
parent3723f15c77c8521a9dbc2d767091b8506b500fdf (diff)
downloadrust-99aa4ed85f15af7c71ea6c2e46eae36f8bc78894.tar.gz
rust-99aa4ed85f15af7c71ea6c2e46eae36f8bc78894.zip
replace config.toml to bootstrap.toml in src/ci, src/etc/* and tests/run-make
Diffstat (limited to 'src/ci')
-rwxr-xr-xsrc/ci/run.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/ci/run.sh b/src/ci/run.sh
index 00bfa1f8ea2..6980d8220e5 100755
--- a/src/ci/run.sh
+++ b/src/ci/run.sh
@@ -229,8 +229,8 @@ trap datecheck EXIT
 # sccache server at the start of the build, but no need to worry if this fails.
 SCCACHE_IDLE_TIMEOUT=10800 sccache --start-server || true
 
-# Our build may overwrite config.toml, so we remove it here
-rm -f config.toml
+# Our build may overwrite bootstrap.toml, so we remove it here
+rm -f bootstrap.toml
 
 $SRC/configure $RUST_CONFIGURE_ARGS